@@ -24,7 +24,7 @@ camera <- function(y,...) UseMethod("camera")
 camera.default <- function(y,index,design=NULL,contrast=ncol(design),weights=NULL,use.ranks=FALSE,allow.neg.cor=FALSE,inter.gene.cor=0.01,trend.var=FALSE,sort=TRUE,...)
 #	Competitive gene set test allowing for correlation between genes
 #	Gordon Smyth and Di Wu
-#	Created 2007.  Last modified 4 June 2016.
+#	Created 2007.  Last modified 30 July 2017.
 {
 #	Issue warning if extra arguments found
 	dots <- names(list(...))
@@ -34,7 +34,7 @@ camera.default <- function(y,index,design=NULL,contrast=ncol(design),weights=NUL
 	y <- getEAWP(y)
 	G <- nrow(y$exprs)
 	n <- ncol(y$exprs)
-	ID <- rownames(y)
+	ID <- rownames(y$exprs)
 	if(G<3) stop("Two few genes in dataset: need at least 3")
 
 #	Check index
